@@ -3,12 +3,15 @@ import requests
 from hashlib import md5
 from .exceptions import MissingParameter
 from .exceptions import ParameterValueError
+import six
 
 try:
     from urllib import urlencode
 except ImportError:
     from urllib.parse import urlencode
 
+def encode_dict(params):
+    return {k:six.u(v).encode('utf-8') if isinstance(v, str) else v.encode('utf-8') if isinstance(v, six.string_types) else v for k, v in six.iteritems(params)}
 
 class Alipay(object):
 
@@ -39,7 +42,7 @@ class Alipay(object):
         params.update({'sign_type': 'MD5',
                        'sign': self._generate_sign(params)})
 
-        return '%s?%s' % (self.GATEWAY_URL, urlencode(params))
+        return '%s?%s' % (self.GATEWAY_URL, urlencode(encode_dict(params)))
 
     def create_direct_pay_by_user_url(self, **kw):
         '''即时到帐'''
